/**
 * Retrieves the translation of text.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-i18n/
 */
import { __ } from '@wordpress/i18n';

/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
import { useBlockProps, RichText } from '@wordpress/block-editor';

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * Those files can contain any CSS code that gets applied to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import './editor.scss';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#edit
 *
 * @return {WPElement} Element to render.
 */
export default function Edit({ attributes, setAttributes }) {
	const blockProps = useBlockProps({
		className: 'asl_custom_t',
	});

	const { plusHead, minusHead, plusBody, minusBody, grayBody } = attributes;

	return (
		<table width="100%" {...blockProps}>
			<tbody>
				<tr>
					<td className="plus">
						<h3>
							<i role="img">✅</i>
							<RichText
								tagName="span"
								allowedFormats={['core/italic']}
								placeholder={__('Plus head', 'asl-blocks')}
								value={plusHead}
								onChange={(newPlusHead) =>
									setAttributes({ plusHead: newPlusHead })
								}
							/>
						</h3>
						<div className="plus-text">
							<RichText
								tagName="ul"
								allowedFormats={['core/italic', 'core/bold']}
								multiline="li"
								withoutInteractiveFormatting={false}
								placeholder={__('Plus text', 'asl-blocks')}
								value={plusBody}
								onChange={(newPlusBody) =>
									setAttributes({ plusBody: newPlusBody })
								}
							/>
						</div>
					</td>
					<td className="minus">
						<h3>
							<i role="img">⛔</i>
							<RichText
								tagName="span"
								allowedFormats={['core/italic']}
								placeholder={__('Minus head', 'asl-blocks')}
								value={minusHead}
								onChange={(newMinusHead) =>
									setAttributes({ minusHead: newMinusHead })
								}
							/>
						</h3>
						<div className="minus-text">
							<RichText
								tagName="ul"
								allowedFormats={['core/italic', 'core/bold']}
								multiline="li"
								placeholder={__('Minus text', 'asl-blocks')}
								withoutInteractiveFormatting={false}
								value={minusBody}
								onChange={(newMinusBody) =>
									setAttributes({ minusBody: newMinusBody })
								}
							/>
						</div>
					</td>
				</tr>
				<tr className="gray_table">
					<td colSpan="2">
						<RichText
							tagName="div"
							allowedFormats={['core/italic', 'core/bold']}
							// multiline="p"
							placeholder={__('Gray text', 'asl-blocks')}
							value={grayBody}
							withoutInteractiveFormatting={true}
							onChange={(newGrayBody) =>
								setAttributes({ grayBody: newGrayBody })
							}
						/>
					</td>
				</tr>
			</tbody>
		</table>
	);
}
