/**
 * Retrieves the translation of text.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-i18n/
 */
import { __ } from '@wordpress/i18n';

/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
import {
	useBlockProps,
	RichText,
	InspectorControls,
	ColorPalette,
	InnerBlocks,
	BlockControls,
	AlignmentToolbar,
} from '@wordpress/block-editor';

import {
	PanelBody,
	RangeControl,
	TextControl,
	ToggleControl,
	RadioControl,
} from '@wordpress/components';

// const ALLOWED_BLOCKS = [ 'core/button' ];
const ALLOWED_BLOCKS = ['core/image'];

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * Those files can contain any CSS code that gets applied to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import './editor.scss';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#edit
 *
 * @return {WPElement} Element to render.
 */
export default function Edit({ attributes, setAttributes }) {
	const {
		alignment,
		title,
		body,
		btnText1,
		btnText2,
		target,
		borderColor,
		borderWidth,
		borderRadius,
		btnStyleFirst,
		btnStyleSecond,
		btnBackgroundFirst,
		btnBackgroundSecond,
		borderRadiusFirst,
		borderRadiusSecond,
		borderWidthFirst,
		borderWidthSecond,
		btnBorderColorFirst,
		btnBorderColorSecond,
		btnLinkFirst,
		btnLinkSecond,
		btnColorFirst,
		btnColorSecond,
		rel,
	} = attributes;

	const blockProps = useBlockProps({
		className: 'asl-cta-1',
	});
	return (
		<>
			<InspectorControls style={{ marginBottom: '40px' }}>
				<PanelBody title={__('Border Template Settings', 'asl-blocks')}>
					<p>
						<strong>
							{__('Select a Border color:', 'asl-blocks')}
						</strong>
					</p>
					<ColorPalette
						value={borderColor}
						onChange={(color) =>
							setAttributes({ borderColor: color })
						}
					/>
					<p>
						<strong>
							{__('Select a Border width:', 'asl-blocks')}
						</strong>
					</p>
					<RangeControl
						label={__('Border Width', 'asl-blocks')}
						value={borderWidth}
						onChange={(width) =>
							setAttributes({ borderWidth: width })
						}
						min={0}
						max={15}
						step={1}
					/>
					<p>
						<strong>Select a Border radius:</strong>
					</p>
					<RangeControl
						label={__('Border Radius', 'asl-blocks')}
						value={borderRadius}
						onChange={(radius) =>
							setAttributes({ borderRadius: radius })
						}
						min={0}
						max={50}
						step={1}
					/>
				</PanelBody>
				<PanelBody title={__('Global Links Settings', 'asl-blocks')}>
					<ToggleControl
						label={__('Open in New Window', 'asl-blocks')}
						checked={target}
						onChange={(state) => {
							setAttributes({ target: state });
						}}
					/>
					<TextControl
						label={__('Add a rel attributes', 'asl-blocks')}
						value={rel}
						onChange={(newRel) => setAttributes({ rel: newRel })}
					/>
				</PanelBody>
				<PanelBody title={__('Buttons Settings', 'asl-blocks')}>
					<h3>{__('First Button Settings', 'asl-blocks')}</h3>
					<TextControl
						label={__('Add link', 'asl-blocks')}
						value={btnLinkFirst}
						onChange={(link) =>
							setAttributes({ btnLinkFirst: link })
						}
					/>

					<RangeControl
						label={__('Border Radius', 'asl-blocks')}
						value={borderRadiusFirst}
						onChange={(radius) =>
							setAttributes({ borderRadiusFirst: radius })
						}
						min={0}
						max={50}
						step={1}
					/>

					<RadioControl
						label={__('Style Button', 'asl-blocks')}
						selected={btnStyleFirst}
						options={[
							{
								label: __('Fill', 'asl-blocks'),
								value: 'fill',
							},
							{
								label: __('Outline', 'asl-blocks'),
								value: 'outline',
							},
						]}
						onChange={(option) =>
							setAttributes({ btnStyleFirst: option })
						}
					/>
					{btnStyleFirst === 'fill' && (
						<>
							<h4>{__('Background Color', 'asl-blocks')}</h4>
							<ColorPalette
								value={btnBackgroundFirst}
								onChange={(color) =>
									setAttributes({
										btnBackgroundFirst: color,
									})
								}
							/>

							<h4>{__('Text Color', 'asl-blocks')}</h4>
							<ColorPalette
								value={btnColorFirst}
								onChange={(color) =>
									setAttributes({ btnColorFirst: color })
								}
							/>
						</>
					)}

					{btnStyleFirst === 'outline' && (
						<>
							<RangeControl
								label={__('Border Width', 'asl-blocks')}
								value={borderWidthFirst}
								onChange={(width) =>
									setAttributes({ borderWidthFirst: width })
								}
								min={0}
								max={10}
								step={1}
							/>

							<h4>{__('Border Color', 'asl-blocks')}</h4>
							<ColorPalette
								value={btnBorderColorFirst}
								onChange={(color) =>
									setAttributes({
										btnBorderColorFirst: color,
									})
								}
							/>
							<h4>{__('Text Color', 'asl-blocks')}</h4>
							<ColorPalette
								value={btnColorFirst}
								onChange={(val) =>
									setAttributes({
										btnColorFirst: val,
									})
								}
							/>
						</>
					)}
					<hr />
					<h3>{__('Second Button Settings', 'asl-blocks')}</h3>
					<TextControl
						label={__('Add link', 'asl-blocks')}
						value={btnLinkSecond}
						onChange={(link) =>
							setAttributes({ btnLinkSecond: link })
						}
					/>
					<RangeControl
						label={__('Border Radius', 'asl-blocks')}
						value={borderRadiusSecond}
						onChange={(radius) =>
							setAttributes({ borderRadiusSecond: radius })
						}
						min={0}
						max={50}
						step={1}
					/>

					<RadioControl
						label={__('Style Button', 'asl-blocks')}
						selected={btnStyleSecond}
						options={[
							{
								label: __('Fill', 'asl-blocks'),
								value: 'fill',
							},
							{
								label: __('Outline', 'asl-blocks'),
								value: 'outline',
							},
						]}
						onChange={(option) => {
							setAttributes({ btnStyleSecond: option });
						}}
					/>
					{btnStyleSecond === 'fill' && (
						<>
							<h4>{__('Background Color', 'asl-blocks')}</h4>
							<ColorPalette
								value={btnBackgroundSecond}
								onChange={(color) =>
									setAttributes({
										btnBackgroundSecond: color,
									})
								}
							/>

							<h4>{__('Text Color', 'asl-blocks')}</h4>
							<ColorPalette
								value={btnColorSecond}
								onChange={(color) =>
									setAttributes({ btnColorSecond: color })
								}
							/>
						</>
					)}

					{btnStyleSecond === 'outline' && (
						<>
							<RangeControl
								label={__('Border Width', 'asl-blocks')}
								value={borderWidthSecond}
								onChange={(width) =>
									setAttributes({
										borderWidthSecond: width,
									})
								}
								min={0}
								max={10}
								step={1}
							/>

							<h4>{__('Border Color', 'asl-blocks')}</h4>
							<ColorPalette
								value={btnBorderColorSecond}
								onChange={(color) =>
									setAttributes({
										btnBorderColorSecond: color,
									})
								}
							/>
							<h4>{__('Text Color', 'asl-blocks')}</h4>
							<ColorPalette
								value={btnColorSecond}
								onChange={(val) =>
									setAttributes({
										btnColorSecond: val,
									})
								}
							/>
						</>
					)}
				</PanelBody>
			</InspectorControls>
			<div
				{...blockProps}
				style={{
					borderColor,
					borderWidth,
					borderRadius,
				}}
			>
				<BlockControls>
					<AlignmentToolbar
						value={alignment}
						onChange={(val) =>
							setAttributes({
								alignment: val === undefined ? 'none' : val,
							})
						}
					/>
				</BlockControls>
				<InnerBlocks allowedBlocks={ALLOWED_BLOCKS} />
				<RichText
					tagName="h3"
					placeholder={__('Your CTA Title', 'asl-blocks')}
					value={title}
					allowedFormats={['core/italic']}
					onChange={(newTitle) => setAttributes({ title: newTitle })}
					style={{ textAlign: alignment }}
				/>

				<div className="asl-cta-1-buttons">
					<RichText
						tagName="a"
						value={btnText1}
						allowedFormats={['core/italic']}
						style={
							btnStyleFirst === 'fill'
								? {
										color: btnColorFirst,
										backgroundColor: btnBackgroundFirst,
										borderRadius: borderRadiusFirst,
								  }
								: {
										borderWidth: borderWidthFirst,
										borderColor: btnBorderColorFirst,
										borderStyle: 'solid',
										color: btnColorFirst,
										borderRadius: borderRadiusFirst,
								  }
						}
						target={target === true ? '_blank' : '_self'}
						href={btnLinkFirst}
						rel={rel}
						onChange={(text) => setAttributes({ btnText1: text })}
						placeholder={__('Type text here', 'asl-blocks')}
						className={
							btnStyleFirst === 'fill'
								? 'asl-btn-cta-1 asl-btn-first asl-fill'
								: 'asl-btn-cta-1 asl-btn-first asl-outline'
						}
					/>
					<RichText
						tagName="a"
						value={btnText2}
						allowedFormats={['core/italic']}
						style={
							btnStyleSecond === 'fill'
								? {
										color: btnColorSecond,
										backgroundColor: btnBackgroundSecond,
										borderRadius: borderRadiusSecond,
								  }
								: {
										borderWidth: borderWidthSecond,
										borderColor: btnBorderColorSecond,
										borderStyle: 'solid',
										color: btnColorSecond,
										borderRadius: borderRadiusSecond,
								  }
						}
						target={target === true ? '_blank' : '_self'}
						href={btnLinkSecond}
						rel={rel}
						onChange={(text) => setAttributes({ btnText2: text })}
						placeholder={__('Type text here', 'asl-blocks')}
						className={
							btnStyleSecond === 'fill'
								? 'asl-btn-cta-1 asl-btn-second asl-fill'
								: 'asl-btn-cta-1 asl-btn-second asl-outline'
						}
					/>
				</div>

				<RichText
					tagName="div"
					className="asl-cta-1-content"
					allowedFormats={['core/italic']}
					multiline="p"
					placeholder={__('Your CTA Description', 'asl-blocks')}
					value={body}
					onChange={(newBody) => setAttributes({ body: newBody })}
				/>
			</div>
		</>
	);
}
