/**
 * Registers a new block provided a unique name and an object defining its behavior.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-registration/
 */
import { registerBlockType } from '@wordpress/blocks';

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * All files containing `style` keyword are bundled together. The code used
 * gets applied both to the front of your site and to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import './style.scss';

/**
 * Internal dependencies
 */
import Edit from './edit';
import save from './save';

/**
 * Every block starts by registering a new block type definition.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-registration/
 */
registerBlockType('asl/cta-1', {
	icon: {
		foreground: '#7e70af',
		src: (
			<svg xmlns="http://www.w3.org/2000/svg">
				<rect fill="none" height="24" width="24" />
				<path d="M11.71,17.99C8.53,17.84,6,15.22,6,12c0-3.31,2.69-6,6-6c3.22,0,5.84,2.53,5.99,5.71l-2.1-0.63C15.48,9.31,13.89,8,12,8 c-2.21,0-4,1.79-4,4c0,1.89,1.31,3.48,3.08,3.89L11.71,17.99z M22,12c0,0.3-0.01,0.6-0.04,0.9l-1.97-0.59C20,12.21,20,12.1,20,12 c0-4.42-3.58-8-8-8s-8,3.58-8,8s3.58,8,8,8c0.1,0,0.21,0,0.31-0.01l0.59,1.97C12.6,21.99,12.3,22,12,22C6.48,22,2,17.52,2,12 C2,6.48,6.48,2,12,2S22,6.48,22,12z M18.23,16.26L22,15l-10-3l3,10l1.26-3.77l4.27,4.27l1.98-1.98L18.23,16.26z" />
			</svg>
		),
	},
	example: {
		attributes: {
			title: 'Title Block',
			alignment: 'center',
			image: 'https://via.placeholder.com/640x140',
			borderColor: '#332e54',
			borderWidth: '2',
			borderRadius: '5',
			btnText1: 'Button 1',
			btnText2: 'Button 2',
		},
		innerBlocks: [
			{
				name: 'core/image',
				attributes: {
					src: 'https://s.w.org/images/core/5.3/Biologia_Centrali-Americana_-_Cantorchilus_semibadius_1902.jpg',
				},
			},
		],
	},
	attributes: {
		title: {
			type: 'string',
			source: 'html',
			selector: 'h3',
		},
		body: {
			type: 'array',
			source: 'children',
			selector: '.asl-cta-1-content',
		},
		alignment: {
			type: 'string',
			default: 'none',
		},
		image: {
			type: 'string',
			default: 'https://via.placeholder.com/640x140',
		},
		borderColor: {
			type: 'string',
			default: '#332e54',
		},
		borderWidth: {
			type: 'number',
			default: 6,
		},
		borderRadius: {
			type: 'number',
			default: 5,
		},
		btnText1: {
			type: 'string',
			default: '',
			source: 'html',
			selector: '.asl-btn-first',
		},
		btnText2: {
			type: 'string',
			default: '',
			source: 'html',
			selector: '.asl-btn-second',
		},
		btnStyleFirst: {
			type: 'string',
			default: 'outline',
		},
		btnStyleSecond: {
			type: 'string',
			default: 'fill',
		},
		btnBackgroundFirst: {
			type: 'string',
			default: '',
		},
		btnBackgroundSecond: {
			type: 'string',
			default: '',
		},
		btnColorFirst: {
			type: 'string',
			default: '',
		},
		btnColorSecond: {
			type: 'string',
			default: '',
		},
		borderRadiusFirst: {
			type: 'number',
			default: 1,
		},
		borderRadiusSecond: {
			type: 'number',
			default: 0,
		},
		borderWidthFirst: {
			type: 'number',
			default: 2,
		},
		borderWidthSecond: {
			type: 'number',
			default: 2,
		},
		btnBorderColorFirst: {
			type: 'string',
			default: '',
		},
		btnBorderColorSecond: {
			type: 'string',
			default: '',
		},
		btnLinkFirst: {
			type: 'string',
			source: 'attribute',
			selector: '.asl-btn-first',
			attribute: 'href',
		},
		btnLinkSecond: {
			type: 'string',
			source: 'attribute',
			selector: '.asl-btn-second',
			attribute: 'href',
		},
		rel: {
			type: 'string',
			source: 'attribute',
			selector: 'a',
			attribute: 'rel',
			default: 'sponsored nofollow',
		},
		target: {
			type: 'boolean',
			default: true,
		},
	},
	/**
	 * @see ./edit.js
	 */
	edit: Edit,

	/**
	 * @see ./save.js
	 */
	save,
});
