/**
 * Retrieves the translation of text.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-i18n/
 */
import { __ } from '@wordpress/i18n';

/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
import {
	useBlockProps,
	RichText,
	InspectorControls,
	ColorPalette,
	InnerBlocks,
} from '@wordpress/block-editor';

import {
	PanelBody,
	TextControl,
	ToggleControl,
	RangeControl,
	RadioControl,
} from '@wordpress/components';

const ALLOWED_BLOCKS = [ 'core/image' ];

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * Those files can contain any CSS code that gets applied to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import './editor.scss';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#edit
 *
 * @return {WPElement} Element to render.
 */
export default function Edit( { attributes, setAttributes } ) {
	const {
		body,
		btnText,
		backgroundColor,
		target,
		rel,
		btnLink,
		btnStyle,
		btnBackground,
		btnColor,
		btnBorderRadius,
		btnBorderWidth,
		btnBorderColor,
	} = attributes;

	const blockProps = useBlockProps( {
		className: 'asl-cta-2',
	} );

	return (
		<>
			<InspectorControls style={ { marginBottom: '40px' } }>
				<PanelBody
					title={ __( 'Background Color Settings', 'asl-blocks' ) }
				>
					<p>
						<strong>
							{ __( 'Select a Background color:', 'asl-blocks' ) }
						</strong>
					</p>
					<ColorPalette
						value={ backgroundColor }
						onChange={ ( color ) =>
							setAttributes( { backgroundColor: color } )
						}
					/>
				</PanelBody>
				<PanelBody title={ __( 'Button Settings', 'asl-blocks' ) }>
					<ToggleControl
						label={ __( 'Open in New Window', 'asl-blocks' ) }
						checked={ target }
						onChange={ ( state ) => {
							setAttributes( { target: state } );
						} }
					/>
					<TextControl
						label={ __( 'Add a rel attributes', 'asl-blocks' ) }
						value={ rel }
						onChange={ ( newRel ) =>
							setAttributes( { rel: newRel } )
						}
					/>
					<TextControl
						label={ __( 'Add link', 'asl-blocks' ) }
						value={ btnLink }
						onChange={ ( newLink ) =>
							setAttributes( { btnLink: newLink } )
						}
					/>

					<RangeControl
						label={ __( 'Border Radius', 'asl-blocks' ) }
						value={ btnBorderRadius }
						onChange={ ( val ) =>
							setAttributes( { btnBorderRadius: val } )
						}
						min={ 0 }
						max={ 50 }
						step={ 1 }
					/>

					<RadioControl
						label={ __( 'Style Button', 'asl-blocks' ) }
						selected={ btnStyle }
						options={ [
							{
								label: __( 'Fill', 'asl-blocks' ),
								value: 'fill',
							},
							{
								label: __( 'Outline', 'asl-blocks' ),
								value: 'outline',
							},
						] }
						onChange={ ( option ) =>
							setAttributes( { btnStyle: option } )
						}
					/>
					{ btnStyle === 'fill' && (
						<>
							<h4>{ __( 'Background Color', 'asl-blocks' ) }</h4>
							<ColorPalette
								value={ btnBackground }
								onChange={ ( color ) =>
									setAttributes( { btnBackground: color } )
								}
							/>

							<h4>{ __( 'Text Color', 'asl-blocks' ) }</h4>
							<ColorPalette
								value={ btnColor }
								onChange={ ( color ) =>
									setAttributes( { btnColor: color } )
								}
							/>
						</>
					) }
					{ btnStyle === 'outline' && (
						<>
							<RangeControl
								label={ __( 'Border Width', 'asl-blocks' ) }
								value={ btnBorderWidth }
								onChange={ ( val ) =>
									setAttributes( { btnBorderWidth: val } )
								}
								min={ 0 }
								max={ 10 }
								step={ 1 }
							/>

							<h4>{ __( 'Border Color', 'asl-blocks' ) }</h4>
							<ColorPalette
								value={ btnBorderColor }
								onChange={ ( val ) =>
									setAttributes( { btnBorderColor: val } )
								}
							/>
							<h4>{ __( 'Text Color', 'asl-blocks' ) }</h4>
							<ColorPalette
								value={ btnColor }
								onChange={ ( val ) =>
									setAttributes( {
										btnColor: val,
									} )
								}
							/>
						</>
					) }
				</PanelBody>
			</InspectorControls>
			<div { ...blockProps } style={ { backgroundColor } }>
				<div className="asl-cta-2-image">
					<InnerBlocks allowedBlocks={ ALLOWED_BLOCKS } />
				</div>

				<div>
					<RichText
						tagName="div"
						multiline="p"
						className="asl-cta-2-text"
						placeholder={ __(
							'Your CTA Description',
							'asl-blocks'
						) }
						value={ body }
						allowedFormats={ [ 'core/italic' ][ 'core/bold' ] }
						onChange={ ( val ) => setAttributes( { body: val } ) }
					/>

					<div
						className="asl-cta-2-buttons"
						style={ { textAlign: 'center' } }
					>
						<RichText
							tagName="a"
							value={ btnText }
							allowedFormats={ [ 'core/italic' ] }
							style={
								btnStyle === 'fill'
									? {
											color: btnColor,
											backgroundColor: btnBackground,
											borderRadius: btnBorderRadius,
									  }
									: {
											borderWidth: btnBorderWidth,
											borderColor: btnBorderColor,
											borderStyle: 'solid',
											color: btnColor,
											borderRadius: btnBorderRadius,
									  }
							}
							target={ target === true ? '_blank' : '_self' }
							href={ btnLink }
							rel={ rel }
							onChange={ ( newLabel ) =>
								setAttributes( {
									btnText: newLabel,
								} )
							}
							placeholder={ __( 'Type text here', 'asl-blocks' ) }
							className={
								btnStyle === 'fill'
									? 'asl-btn-cta-2 asl-fill'
									: 'asl-btn-cta-2 asl-outline'
							}
						/>
					</div>
				</div>
			</div>
		</>
	);
}
