/**
 * Retrieves the translation of text.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-i18n/
 */
import { __ } from '@wordpress/i18n';

/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
import {
	InnerBlocks,
	RichText,
	InspectorControls,
	useBlockProps,
	ColorPalette,
} from '@wordpress/block-editor';

import {
	PanelBody,
	RangeControl,
	TextControl,
	ToggleControl,
} from '@wordpress/components';

const ALLOWED_BLOCKS = [ 'core/image' ];

import './editor.scss';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#edit
 *
 * @return {WPElement} Element to render.
 */
export default function Edit( { attributes, setAttributes } ) {
	const {
		number,
		heading,
		postList,
		label,
		btnText,
		styleLabel,
		target,
		btnBorderRadius,
		btnBackground,
		btnColor,
		link,
		rel,
		zoomBtn,
	} = attributes;

	const blockProps = useBlockProps( {
		className: 'asl-product__row',
	} );

	return (
		<>
			<InspectorControls style={ { marginBottom: 40 } }>
				<PanelBody title={ __( 'Link Settings', 'asl-blocks' ) }>
					<TextControl
						label={ __( 'Add a link', 'asl-blocks' ) }
						value={ link }
						onChange={ ( newLink ) =>
							setAttributes( { link: newLink } )
						}
					/>

					<TextControl
						label={ __( 'Add a rel attributes', 'asl-blocks' ) }
						value={ rel }
						onChange={ ( newRel ) =>
							setAttributes( { rel: newRel } )
						}
					/>
					<ToggleControl
						label={ __( 'Open in New Window', 'asl-blocks' ) }
						checked={ target }
						onChange={ ( newTarget ) => {
							setAttributes( { target: newTarget } );
						} }
					/>
				</PanelBody>
				<PanelBody
					title={ __( 'Button Settings', 'asl-blocks' ) }
					initialOpen={ true }
				>
					<ToggleControl
						label={ __(
							'Zoom Animation Button',
							'asl-blocks'
						) }
						checked={ zoomBtn }
						onChange={ ( state ) =>
							setAttributes( { zoomBtn: state } )
						}
					/>
					<RangeControl
						label="Border Radius"
						value={ btnBorderRadius }
						onChange={ ( radius ) =>
							setAttributes( { btnBorderRadius: radius } )
						}
						min={ 0 }
						max={ 20 }
					/>
					<>
						<p>
							<strong>
								{ __(
									'Select a Background color:',
									'asl-blocks'
								) }
							</strong>
						</p>
						<ColorPalette
							value={ btnBackground }
							onChange={ ( val ) =>
								setAttributes( {
									btnBackground: val,
								} )
							}
						/>
						<p>
							<strong>
								{ __( 'Select a Text color:', 'asl-blocks' ) }
							</strong>
						</p>
						<ColorPalette
							value={ btnColor }
							onChange={ ( newBtnColor ) =>
								setAttributes( { btnColor: newBtnColor } )
							}
						/>
					</>
				</PanelBody>
				<PanelBody
					title={ __( 'Other Settings', 'asl-blocks' ) }
					initialOpen={ true }
				>
					<ToggleControl
						label={ __( 'Fill style label', 'asl-blocks' ) }
						checked={ styleLabel }
						onChange={ () => {
							setAttributes( { styleLabel: ! styleLabel } );
						} }
					/>
				</PanelBody>
			</InspectorControls>
			<div { ...blockProps }>
				<div className="asl-product__column_0 asl-product__column">
					<RichText
						tagName="p"
						value={ number }
						allowedFormats={ [ 'core/italic' ] }
						onChange={ ( newPostList ) =>
							setAttributes( {
								number: newPostList,
							} )
						}
						className="asl-table-number"
						placeholder={ __( '1', 'asl-blocks' ) }
					/>
				</div>
				<div className="asl-product__column_1 asl-product__column">
					<InnerBlocks allowedBlocks={ ALLOWED_BLOCKS } />
				</div>
				<div className="asl-product__column_2 asl-product__column">
					<RichText
						tagName="div"
						value={ label }
						allowedFormats={ [ 'core/italic' ] }
						onChange={ ( newPostList ) =>
							setAttributes( {
								label: newPostList,
							} )
						}
						className={
							styleLabel
								? 'asl-product__link-label asl-table-label'
								: 'asl-product__label asl-table-label'
						}
						placeholder={ __( 'Type here', 'asl-blocks' ) }
					/>

					<RichText
						tagName="a"
						href={ link }
						target={ target ? '_blank' : '_self' }
						rel={ rel }
						value={ heading }
						allowedFormats={ [ 'core/italic' ] }
						onChange={ ( newPostList ) =>
							setAttributes( {
								heading: newPostList,
							} )
						}
						className="asl-product-heading"
						placeholder={ __( 'Type here', 'asl-blocks' ) }
					/>
				</div>
				<div className="asl-product__column_3 asl-product__column">
					<RichText
						tagName="ul"
						value={ postList }
						allowedFormats={ [ 'core/bold', 'core/italic' ] }
						onChange={ ( newPostList ) =>
							setAttributes( { postList: newPostList } )
						}
						className="asl-product-table__list"
						placeholder={ __( 'Text here', 'asl-blocks' ) }
						multiline="li"
					/>
				</div>
				<div className="asl-product__column_4 asl-product__column">
					<span className={ zoomBtn ? 'btn-zoom start-zoom' : '' }>
						<RichText
							tagName="a"
							value={ btnText }
							allowedFormats={ [ 'core/italic' ] }
							onChange={ ( newPostList ) =>
								setAttributes( {
									btnText: newPostList,
								} )
							}
							rel={ rel }
							href={ link }
							target={ target ? '_blank' : '_self' }
							className="asl-btn-pt"
							placeholder={ __( 'Type here', 'asl-blocks' ) }
							style={ {
								borderRadius: btnBorderRadius,
								color: btnColor,
								backgroundColor: btnBackground,
							} }
						/>
					</span>
				</div>
			</div>
		</>
	);
}
