/**
 * Retrieves the translation of text.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-i18n/
 */
import { __ } from '@wordpress/i18n';

const ALLOWED_BLOCKS = [ 'core/image' ];

/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
import {
	useBlockProps,
	InspectorControls,
	RichText,
	InnerBlocks,
	ColorPalette,
} from '@wordpress/block-editor';

import {
	Panel,
	PanelBody,
	PanelRow,
	SelectControl,
	ToggleControl,
	TextControl,
	RangeControl,
} from '@wordpress/components';

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * Those files can contain any CSS code that gets applied to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import './editor.scss';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#edit
 *
 * @return {JSX.Element} Element to render.
 */
export default function Edit( { attributes, setAttributes } ) {
	const {
		count,
		label,
		title,
		secondTitle,
		postContent,
		btnText,
		postList,
		template,
		btnBorderWidth,
		btnBorderRadius,
		btnBackground,
		btnBorder,
		animationBtn,
		link,
		btnColor,
		zoomBtn,
		rel,
		target,
		twoComponent,
	} = attributes;
	return (
		<div { ...useBlockProps() }>
			<InspectorControls style={ { marginBottom: '40px' } }>
				<Panel>
					<PanelBody
						title={ __( 'Global Settings', 'asl-blocks' ) }
						initialOpen={ true }
					>
						<SelectControl
							label={ __( 'Select template:', 'asl-blocks' ) }
							value={ template }
							onChange={ ( newTemplate ) =>
								setAttributes( { template: newTemplate } )
							}
							options={ [
								{
									value: 't1',
									label: __( 'Template 1', 'asl-blocks' ),
								},
								{
									value: 't2',
									label: __( 'Template 2', 'asl-blocks' ),
								},
								{
									value: 't3',
									label: __( 'Template 3', 'asl-blocks' ),
								},
							] }
						/>
						<hr />
						<PanelRow>
							<h3>{ __( 'Links Settings', 'asl-blocks' ) }</h3>
						</PanelRow>
						<TextControl
							label={ __( 'Add a rel attributes', 'asl-blocks' ) }
							value={ rel }
							onChange={ ( newRel ) =>
								setAttributes( { rel: newRel } )
							}
						/>
						<TextControl
							label={ __( 'Add link', 'asl-blocks' ) }
							value={ link }
							onChange={ ( newLink ) =>
								setAttributes( { link: newLink } )
							}
						/>
						<ToggleControl
							label={ __( 'Open in a new Window', 'asl-blocks' ) }
							checked={ target }
							onChange={ ( state ) =>
								setAttributes( { target: state } )
							}
						/>
						<ToggleControl
							label={ __( 'Add a list component', 'asl-blocks' ) }
							checked={ twoComponent }
							onChange={ ( state ) =>
								setAttributes( { twoComponent: state } )
							}
						/>
					</PanelBody>
				</Panel>
				<Panel>
					<PanelBody title={ __( 'Button Settings', 'asl-blocks' ) }>
						<ToggleControl
							label={ __(
								'Zoom Animation Button',
								'asl-blocks'
							) }
							checked={ zoomBtn }
							onChange={ ( state ) =>
								setAttributes( { zoomBtn: state } )
							}
						/>
						<ToggleControl
							label={ __(
								'Pulses Animation Button',
								'asl-blocks'
							) }
							checked={ animationBtn }
							onChange={ ( state ) =>
								setAttributes( { animationBtn: state } )
							}
						/>
						<hr />
						<RangeControl
							label={ __( 'Border Radius', 'asl-blocks' ) }
							value={ btnBorderRadius }
							onChange={ ( radius ) =>
								setAttributes( { btnBorderRadius: radius } )
							}
							min={ 0 }
							max={ 50 }
							step={ 1 }
						/>
						<hr />
						<RangeControl
							label={ __( 'Border Width', 'asl-blocks' ) }
							value={ btnBorderWidth }
							onChange={ ( width ) =>
								setAttributes( { btnBorderWidth: width } )
							}
							min={ 0 }
							max={ 50 }
							step={ 1 }
						/>
						<hr />
						<div>
							<h3>{ __( 'Text Color', 'asl-blocks' ) }</h3>
							<ColorPalette
								value={ btnColor }
								onChange={ ( color ) =>
									setAttributes( { btnColor: color } )
								}
							/>
							<hr />
							<h3>{ __( 'Background Color', 'asl-blocks' ) }</h3>
							<ColorPalette
								value={ btnBackground }
								onChange={ ( color ) =>
									setAttributes( { btnBackground: color } )
								}
							/>
							<hr />
							<h3>{ __( 'Border Color', 'asl-blocks' ) }</h3>
							<ColorPalette
								value={ btnBorder }
								onChange={ ( color ) =>
									setAttributes( { btnBorder: color } )
								}
							/>
						</div>
					</PanelBody>
				</Panel>
			</InspectorControls>
			{ template === 't1' && (
				<div
					className="product_wrap-2 product_wrap-2-nc asl-product"
					data-template="t1"
				>
					<div className="product-flex">
						<div className="product_block-2">
							<div className="product_block-2__label-wrap">
								<RichText
									tagName="div"
									value={ label }
									onChange={ ( newLabel ) =>
										setAttributes( { label: newLabel } )
									}
									placeholder={ __( 'Type text here' ) }
									className={
										'product_block-2__label asl-label'
									}
								/>
							</div>
							<div className="product_block-2__column-image">
								<RichText
									tagName="div"
									value={ count }
									onChange={ ( newCount ) =>
										setAttributes( { count: newCount } )
									}
									allowedFormats={ [] }
									placeholder={ __( '1' ) }
									className={
										'product_block-new__count asl-count'
									}
								/>
								<div className="product-image-container">
									<InnerBlocks
										allowedBlocks={ ALLOWED_BLOCKS }
									/>
								</div>
								<div
									className={
										zoomBtn === true
											? 'btn-box btn-zoom'
											: 'btn-box'
									}
								>
									<RichText
										tagName="a"
										value={ btnText }
										style={ {
											color: btnColor,
											backgroundColor: btnBackground,
											borderWidth: btnBorderWidth,
											borderColor: btnBorder,
											borderStyle: 'solid',
											borderRadius: btnBorderRadius,
										} }
										target={
											target === true ? '_blank' : '_self'
										}
										href={ link }
										rel={ rel }
										onChange={ ( newLabel ) =>
											setAttributes( {
												btnText: newLabel,
											} )
										}
										placeholder={ __(
											'Type text here',
											'asl-blocks'
										) }
										className={
											animationBtn === true
												? 'asl-btn btn_item__button pulses'
												: 'asl-btn btn_item__button'
										}
									/>
								</div>
							</div>
							<div className="product_block-2__column-content">
								<div className="product_block-2__bar" />
								<div className="product_block-2__title">
									<RichText
										tagName="a"
										value={ secondTitle }
										href={ link }
										target={
											target === true ? '_blank' : '_self'
										}
										rel={ rel }
										onChange={ ( newTitle ) =>
											setAttributes( {
												secondTitle: newTitle,
											} )
										}
										placeholder={ __(
											'Text type here',
											'asl-blocks'
										) }
										className={ 'asl-product__heading' }
									/>
								</div>
								<RichText
									tagName="div"
									value={ title }
									onChange={ ( newTitle ) =>
										setAttributes( { title: newTitle } )
									}
									placeholder={ __(
										'Text type here',
										'asl-blocks'
									) }
									className={
										'title asl-product__subheading'
									}
								/>
								<RichText
									tagName="span"
									value={ postContent }
									allowedFormats={ [
										'core/bold',
										'core/italic',
									] }
									onChange={ ( newPostContent ) =>
										setAttributes( {
											postContent: newPostContent,
										} )
									}
									className="description asl-product__description"
									placeholder={ __(
										'Text here',
										'asl-blocks'
									) }
									multiline="p"
								/>
								{ twoComponent === true && (
									<>
										<div className="product_block-2__bar" />
										<RichText
											tagName="ul"
											value={ postList }
											allowedFormats={ [
												'core/bold',
												'core/italic',
											] }
											onChange={ ( newPostList ) =>
												setAttributes( {
													postList: newPostList,
												} )
											}
											className="asl-product__list"
											placeholder={ __(
												'Text here',
												'asl-blocks'
											) }
											multiline="li"
										/>
									</>
								) }
							</div>
						</div>
					</div>
				</div>
			) }
			{ template === 't2' && (
				<div
					className="product_wrap old-count asl-product"
					data-template="t2"
				>
					<div className="product_block">
						<RichText
							tagName="div"
							value={ count }
							onChange={ ( newCount ) =>
								setAttributes( { count: newCount } )
							}
							placeholder={ __( '1' ) }
							className={ 'count-o asl-count' }
							allowedFormats={ [] }
						/>
						<div className="label-wrap">
							<RichText
								tagName="div"
								value={ label }
								onChange={ ( newLabel ) =>
									setAttributes( { label: newLabel } )
								}
								placeholder={ __(
									'Type text here',
									'asl-blocks'
								) }
								className={ 'label asl-label' }
							/>
						</div>
						<div className="product_block-wrapper">
							<div className="product_block-inner">
								<div className="group">
									<div className="product-image">
										<InnerBlocks
											allowedBlocks={ ALLOWED_BLOCKS }
										/>
									</div>
									<div className="meta">
										<div className="product-name">
											<RichText
												tagName="a"
												value={ secondTitle }
												href={ link }
												target={
													target === true
														? '_blank'
														: '_self'
												}
												rel={ rel }
												onChange={ ( newTitle ) =>
													setAttributes( {
														secondTitle: newTitle,
													} )
												}
												placeholder={ __(
													'Text type here',
													'asl-blocks'
												) }
												className={
													'name asl-product__heading'
												}
											/>
										</div>
										<RichText
											tagName="div"
											value={ title }
											onChange={ ( newTitle ) =>
												setAttributes( {
													title: newTitle,
												} )
											}
											placeholder={ __(
												'Text type here',
												'asl-blocks'
											) }
											className={
												'title asl-product__subheading'
											}
										/>
										<RichText
											tagName="span"
											value={ postContent }
											allowedFormats={ [
												'core/bold',
												'core/italic',
												'core/list',
											] }
											onChange={ ( newPostContent ) =>
												setAttributes( {
													postContent: newPostContent,
												} )
											}
											className="description asl-product__description"
											placeholder={ __(
												'Text here',
												'asl-blocks'
											) }
											multiline="p"
										/>
										{ twoComponent === true && (
											<>
												<div className="product_block-2__bar" />
												<RichText
													tagName="ul"
													value={ postList }
													allowedFormats={ [
														'core/bold',
														'core/italic',
													] }
													onChange={ (
														newPostContent
													) =>
														setAttributes( {
															postList: newPostContent,
														} )
													}
													className="asl-product__list"
													placeholder={ __(
														'Text here',
														'asl-blocks'
													) }
													multiline="li"
												/>
											</>
										) }
										<div className="product-pricebox-sources">
											<div
												className={
													zoomBtn === true
														? 'btn-box btn-zoom'
														: 'btn-box'
												}
											>
												<RichText
													tagName="a"
													value={ btnText }
													style={ {
														color: btnColor,
														backgroundColor: btnBackground,
														borderWidth: btnBorderWidth,
														borderColor: btnBorder,
														borderStyle: 'solid',
														borderRadius: btnBorderRadius,
													} }
													target={
														target === true
															? '_blank'
															: '_self'
													}
													href={ link }
													rel={ rel }
													onChange={ ( newLabel ) =>
														setAttributes( {
															btnText: newLabel,
														} )
													}
													placeholder={ __(
														'Type text here',
														'asl-blocks'
													) }
													className={
														animationBtn === true
															? 'asl-btn btn btn-size-normal pulses'
															: 'asl-btn btn btn-size-normal'
													}
												/>
											</div>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			) }
			{ template === 't3' && (
				<div
					className="product_wrap product_wrap-oc asl-product"
					data-template="t3"
				>
					<div className="product_block color">
						<RichText
							tagName="div"
							value={ label }
							onChange={ ( newLabel ) =>
								setAttributes( { label: newLabel } )
							}
							placeholder={ __( 'Type text here', 'asl-blocks' ) }
							className={ 'label asl-label' }
						/>
						<div className="product_block-wrapper">
							<RichText
								tagName="div"
								value={ count }
								onChange={ ( newCount ) =>
									setAttributes( { count: newCount } )
								}
								placeholder={ __( '1' ) }
								className={
									'product_block-count color asl-count'
								}
								allowedFormats={[]}
							/>
							<div className="product_block-inner">
								<div className="group">
									<div className="product-image">
										<InnerBlocks
											allowedBlocks={ ALLOWED_BLOCKS }
										/>
									</div>
									<div className="meta">
										<div className="product-name">
											<RichText
												tagName="a"
												value={ secondTitle }
												href={ link }
												target={
													target === true
														? '_blank'
														: '_self'
												}
												rel={ rel }
												onChange={ ( newTitle ) =>
													setAttributes( {
														secondTitle: newTitle,
													} )
												}
												placeholder={ __(
													'Text type here',
													'asl-blocks'
												) }
												className={
													'asl-product__heading'
												}
											/>
										</div>
										<RichText
											tagName="div"
											value={ title }
											onChange={ ( newTitle ) =>
												setAttributes( {
													title: newTitle,
												} )
											}
											placeholder={ __(
												'Text type here',
												'asl-blocks'
											) }
											className={
												'title asl-product__subheading'
											}
										/>
										<RichText
											tagName="span"
											value={ postContent }
											allowedFormats={ [
												'core/bold',
												'core/italic',
											] }
											onChange={ ( newPostContent ) =>
												setAttributes( {
													postContent: newPostContent,
												} )
											}
											className="description asl-product__description"
											placeholder={ __(
												'Text here',
												'asl-blocks'
											) }
											multiline="p"
										/>
										{ twoComponent === true && (
											<>
												<div className="product_block-2__bar" />
												<RichText
													tagName="ul"
													value={ postList }
													allowedFormats={ [
														'core/bold',
														'core/italic',
													] }
													onChange={ (
														newPostContent
													) =>
														setAttributes( {
															postList: newPostContent,
														} )
													}
													className="asl-product__list"
													placeholder={ __(
														'Text here',
														'asl-blocks'
													) }
													multiline="li"
												/>
											</>
										) }
										<div className="product-pricebox-sources">
											<div
												className={
													zoomBtn === true
														? 'btn-box btn-zoom'
														: 'btn-box'
												}
											>
												<RichText
													tagName="a"
													value={ btnText }
													allowedFormats={ [
														'core/bold',
													] }
													style={ {
														color: btnColor,
														backgroundColor: btnBackground,
														borderWidth: btnBorderWidth,
														borderColor: btnBorder,
														borderStyle: 'solid',
														borderRadius: btnBorderRadius,
													} }
													target={
														target === true
															? '_blank'
															: '_self'
													}
													href={ link }
													rel={ rel }
													onChange={ ( newLabel ) =>
														setAttributes( {
															btnText: newLabel,
														} )
													}
													placeholder={ __(
														'Type text here',
														'asl-blocks'
													) }
													className={
														animationBtn === true
															? 'asl-btn btn btn-size-normal pulses'
															: 'asl-btn btn btn-size-normal'
													}
												/>
											</div>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			) }
		</div>
	);
}
