/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/packages/packages-block-editor/#useBlockProps
 */
import { InnerBlocks, RichText, useBlockProps } from '@wordpress/block-editor';

/**
 * The save function defines the way in which the different attributes should
 * be combined into the final markup, which is then serialized by the block
 * editor into `post_content`.
 *
 * @see https://developer.wordpress.org/block-editor/developers/block-api/block-edit-save/#save
 *
 * @return {WPElement} Element to render.
 */
export default function save( { attributes } ) {
	const {
		template,
		count,
		label,
		title,
		secondTitle,
		postContent,
		btnText,
		btnBorderWidth,
		btnBorderRadius,
		btnBackground,
		btnBorder,
		animationBtn,
		link,
		btnColor,
		zoomBtn,
		target,
		rel,
		twoComponent,
		postList,
	} = attributes;

	return (
		<div { ...useBlockProps.save() }>
			{ template === 't1' && (
				<div
					className="product_wrap-2 product_wrap-2-nc asl-product"
					data-template="t1"
				>
					<div className="product-flex">
						<div className="product_block-2">
							<div className="product_block-2__label-wrap">
								<RichText.Content
									tagName="div"
									value={ label }
									className={
										'product_block-2__label asl-label'
									}
								/>
							</div>
							<div className="product_block-2__column-image">
								{ count !== '' && (
									<RichText.Content
										tagName="div"
										value={ count }
										className={
											'product_block-new__count asl-count'
										}
									/>
								) }

								<div className="product-image-container">
									<InnerBlocks.Content />
								</div>
								<div
									className={
										zoomBtn === true
											? 'btn-box btn-zoom'
											: 'btn-box'
									}
								>
									<RichText.Content
										tagName="a"
										value={ btnText }
										style={ {
											color: btnColor,
											backgroundColor: btnBackground,
											borderWidth: btnBorderWidth,
											borderColor: btnBorder,
											borderStyle: 'solid',
											borderRadius: btnBorderRadius,
										} }
										target={
											target === true ? '_blank' : '_self'
										}
										href={ link }
										rel={ rel }
										className={
											animationBtn === true
												? 'asl-btn btn_item__button pulses'
												: 'asl-btn btn_item__button'
										}
									/>
								</div>
							</div>
							<div className="product_block-2__column-content">
								<div className="product_block-2__bar" />
								<div className="product_block-2__title">
									<RichText.Content
										tagName="a"
										value={ secondTitle }
										href={ link }
										target={
											target === true ? '_blank' : '_self'
										}
										rel={ rel }
										className={ 'asl-product__heading' }
									/>
								</div>
								<RichText.Content
									tagName="div"
									value={ title }
									className={
										'title asl-product__subheading'
									}
								/>
								<RichText.Content
									tagName="span"
									value={ postContent }
									className="description asl-product__description"
									multiline="p"
								/>
								{ twoComponent === true && (
									<>
										<div className="product_block-2__bar" />
										<RichText.Content
											tagName="ul"
											value={ postList }
											className="asl-product__list"
											multiline="li"
										/>
									</>
								) }
							</div>
						</div>
					</div>
				</div>
			) }
			{ template === 't2' && (
				<div
					className="product_wrap old-count asl-product"
					data-template="t2"
				>
					<div className="product_block">
						{ count !== '' && (
							<RichText.Content
								tagName="div"
								value={ count }
								className={ 'count-o asl-count' }
							/>
						) }

						<div className="label-wrap">
							<RichText.Content
								tagName="div"
								value={ label }
								className={ 'label asl-label' }
							/>
						</div>
						<div className="product_block-wrapper">
							<div className="product_block-inner">
								<div className="group">
									<div className="product-image">
										<InnerBlocks.Content />
									</div>
									<div className="meta">
										<div className="product-name">
											<RichText.Content
												tagName="a"
												value={ secondTitle }
												href={ link }
												target={
													target === true
														? '_blank'
														: '_self'
												}
												rel={ rel }
												className={
													'name asl-product__heading'
												}
											/>
										</div>
										<RichText.Content
											tagName="div"
											value={ title }
											className={
												'title asl-product__subheading'
											}
										/>
										<RichText.Content
											tagName="span"
											value={ postContent }
											allowedFormats={ [
												'core/bold',
												'core/italic',
											] }
											className="description asl-product__description"
											multiline="p"
										/>
										{ twoComponent === true && (
											<>
												<div className="product_block-2__bar" />
												<RichText.Content
													tagName="ul"
													value={ postList }
													className="asl-product__list"
													multiline="li"
												/>
											</>
										) }
										<div className="product-pricebox-sources">
											<div
												className={
													zoomBtn === true
														? 'btn-box btn-zoom'
														: 'btn-box'
												}
											>
												<RichText.Content
													tagName="a"
													value={ btnText }
													style={ {
														color: btnColor,
														backgroundColor: btnBackground,
														borderWidth: btnBorderWidth,
														borderColor: btnBorder,
														borderStyle: 'solid',
														borderRadius: btnBorderRadius,
													} }
													target={
														target === true
															? '_blank'
															: '_self'
													}
													href={ link }
													rel={ rel }
													className={
														animationBtn === true
															? 'asl-btn btn btn-size-normal pulses'
															: 'asl-btn btn btn-size-normal'
													}
												/>
											</div>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			) }
			{ template === 't3' && (
				<div
					className="product_wrap product_wrap-oc asl-product"
					data-template="t3"
				>
					<div className="product_block color">
						<RichText.Content
							tagName="div"
							value={ label }
							className={ 'label asl-label' }
						/>
						<div className="product_block-wrapper">
							{ count !== '' && (
								<RichText.Content
									tagName="div"
									value={ count }
									className={
										'product_block-count color asl-count'
									}
								/>
							) }
							<div className="product_block-inner">
								<div className="group">
									<div className="product-image">
										<InnerBlocks.Content />
									</div>
									<div className="meta">
										<div className="product-name">
											<RichText.Content
												tagName="a"
												value={ secondTitle }
												href={ link }
												target={
													target === true
														? '_blank'
														: '_self'
												}
												rel={ rel }
												className={
													'asl-product__heading'
												}
											/>
										</div>
										<RichText.Content
											tagName="div"
											value={ title }
											className={
												'title asl-product__subheading'
											}
										/>
										<RichText.Content
											tagName="span"
											value={ postContent }
											className="description asl-product__description"
											multiline="p"
										/>
										{ twoComponent === true && (
											<>
												<div className="product_block-2__bar" />
												<RichText.Content
													tagName="ul"
													value={ postList }
													className="asl-product__list"
													multiline="li"
												/>
											</>
										) }
										<div className="product-pricebox-sources">
											<div
												className={
													zoomBtn === true
														? 'btn-box btn-zoom'
														: 'btn-box'
												}
											>
												<RichText.Content
													tagName="a"
													value={ btnText }
													style={ {
														color: btnColor,
														backgroundColor: btnBackground,
														borderWidth: btnBorderWidth,
														borderColor: btnBorder,
														borderStyle: 'solid',
														borderRadius: btnBorderRadius,
													} }
													target={
														target === true
															? '_blank'
															: '_self'
													}
													href={ link }
													rel={ rel }
													className={
														animationBtn === true
															? 'asl-btn btn btn-size-normal pulses'
															: 'asl-btn btn btn-size-normal'
													}
												/>
											</div>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			) }
		</div>
	);
}
